Detects variable status given a DAG (exposure, outcome, latent). See
dagitty::VariableStatus() for details.
Usage
node_status(.dag, as_factor = TRUE, ...)
ggdag_status(
.tdy_dag,
...,
size = 1,
edge_type = c("link_arc", "link", "arc", "diagonal"),
node_size = ggdag_option("node_size", 16),
text_size = ggdag_option("text_size", 3.88),
label_size = ggdag_option("label_size", text_size),
text_col = ggdag_option("text_col", "white"),
label_col = ggdag_option("label_col", "black"),
edge_width = ggdag_option("edge_width", 0.6),
edge_cap = ggdag_option("edge_cap", 8),
arrow_length = ggdag_option("arrow_length", 5),
use_edges = ggdag_option("use_edges", TRUE),
use_nodes = ggdag_option("use_nodes", TRUE),
use_stylized = ggdag_option("use_stylized", FALSE),
use_text = ggdag_option("use_text", TRUE),
use_labels = ggdag_option("use_labels", FALSE),
label_geom = ggdag_option("label_geom", geom_dag_label_repel),
unified_legend = TRUE,
text = NULL,
label = NULL,
node = deprecated(),
stylized = deprecated()
)Arguments
- .dag, .tdy_dag
input graph, an object of class
tidy_dagittyordagitty- as_factor
treat
statusvariable as factor- ...
additional arguments passed to
tidy_dagitty()- size
A numeric value scaling the size of all elements in the DAG. This allows you to change the scale of the DAG without changing the proportions.
- edge_type
The type of edge, one of "link_arc", "link", "arc", "diagonal".
- node_size
The size of the nodes.
- text_size
The size of the text.
- label_size
The size of the labels.
- text_col
The color of the text.
- label_col
The color of the labels.
- edge_width
The width of the edges.
- edge_cap
The size of edge caps (the distance between the arrowheads and the node borders).
- arrow_length
The length of arrows on edges.
- use_edges
A logical value. Include a
geom_dag_edges*()function? IfTRUE, which is determined byedge_type.- use_nodes
A logical value. Include
geom_dag_point()?- use_stylized
A logical value. Include
geom_dag_node()?- use_text
A logical value. Include
geom_dag_text()?- use_labels
A logical value. Include a label geom? The specific geom used is controlled by
label_geom.- label_geom
A geom function to use for drawing labels when
use_labels = TRUE. Default isgeom_dag_label_repel. Other options includegeom_dag_label,geom_dag_text_repel,geom_dag_label_repel2, andgeom_dag_text_repel2.- unified_legend
A logical value. When
TRUEand bothuse_edgesanduse_nodesareTRUE, creates a unified legend entry showing both nodes and edges in a single key, and hides the separate edge legend. This creates cleaner, more compact legends. Default isTRUE.- text
The bare name of a column to use for
geom_dag_text(). Ifuse_text = TRUE, the default is to usename.- label
The bare name of a column to use for labels. If
use_labels = TRUE, the default is to uselabel.- node
Deprecated.
- stylized
Deprecated.
Examples
dag <- dagify(
l ~ x + y,
y ~ x,
exposure = "x",
outcome = "y",
latent = "l"
)
node_status(dag)
#> # DAG:
#> # A `dagitty` DAG with: 3 nodes and 3 edges
#> # Exposure: x
#> # Outcome: y
#> # Latent Variable: l
#> #
#> # Data:
#> # A tibble: 4 × 8
#> name x y direction to xend yend status
#> <chr> <dbl> <dbl> <fct> <chr> <dbl> <dbl> <fct>
#> 1 l 5.02e- 1 0.290 NA NA NA NA latent
#> 2 x -5.02e- 1 0.290 -> l 5.02e- 1 0.290 exposure
#> 3 x -5.02e- 1 0.290 -> y 5.23e-13 -0.580 exposure
#> 4 y 5.23e-13 -0.580 -> l 5.02e- 1 0.290 outcome
#> #
#> # ℹ Use `pull_dag() (`?pull_dag`)` to retrieve the DAG object and `pull_dag_data() (`?pull_dag_data`)` for the data frame
ggdag_status(dag)